@@ -1,4 +1,4 @@
-// $Id: AppData.h,v 1.130 2000/02/11 23:00:30 andreas Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.139 2001/01/17 13:44:56 zeller Exp $ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
@@ -90,12 +90,14 @@
 #define XtNdefaultFont           "defaultFont"
 #define XtNvariableWidthFont     "variableWidthFont"
 #define XtNfixedWidthFont        "fixedWidthFont"
+#define XtNdataFont              "dataFont"
 #ifndef XtCFont
 #define XtCFont                  "Font"
 #endif
 #define XtNdefaultFontSize       "defaultFontSize"
 #define XtNvariableWidthFontSize "variableWidthFontSize"
 #define XtNfixedWidthFontSize    "fixedWidthFontSize"
+#define XtNdataFontSize          "dataFontSize"
 #define XtCFontSize              "FontSize"
 #define XtNfontSelectCommand     "fontSelectCommand"
 #define XtCFontSelectCommand     "FontSelectCommand"
@@ -115,6 +117,8 @@
 #define XtCSourceEditing         "SourceEditing"
 #define XtNlineBufferedConsole   "lineBufferredConsole"
 #define XtCLineBuffered          "LineBuffered"
+#define XtNconsoleHasFocus       "consoleHasFocus"
+#define XtCConsoleHasFocus       "ConsoleHasFocus"
 #define XtNgdbDisplayShortcuts   "gdbDisplayShortcuts"
 #define XtNdbxDisplayShortcuts   "dbxDisplayShortcuts"
 #define XtNxdbDisplayShortcuts   "xdbDisplayShortcuts"
@@ -173,6 +177,11 @@
 #define XtCSynchronousDebugger   "SynchronousDebugger"
 #define XtNterminateOnEOF        "terminateOnEOF"
 #define XtCTerminateOnEOF        "TerminateOnEOF"
+#define XtNstopAndContinue       "stopAndContinue"
+#define XtCStopAndContinue       "StopAndContinue"
+#define XtNrunInterruptDelay     "runInterruptDelay"
+#define XtNcontInterruptDelay    "contInterruptDelay"
+#define XtCInterruptDelay        "InterruptDelay"
 #define XtNpollChildStatus       "pollChildStatus"
 #define XtCPollChildStatus       "PollChildStatus"
 #define XtNdebuggerHost          "debuggerHost"
@@ -259,6 +268,8 @@
 #define XtCAnnotate              "Annotate"
 #define XtNblockTTYInput         "blockTTYInput"
 #define XtCBlockTTYInput         "BlockTTYInput"
+#define XtNbufferGDBOutput       "bufferGDBOutput"
+#define XtCBufferGDBOutput       "BufferGDBOutput"
 #define XtNdisplayGlyphs         "displayGlyphs"
 #define XtCDisplayGlyphs         "DisplayGlyphs"
 #define XtNmaxGlyphs             "maxGlyphs"
@@ -339,6 +350,7 @@
 #define XtCShowDisplayTitles     "ShowDisplayTitles"
 #define XtNclusterDisplays       "clusterDisplays"
 #define XtCClusterDisplays       "ClusterDisplays"
+#define XtNdisplayPlacement      "displayPlacement"
 #define XtNstatusHistorySize     "statusHistorySize"
 #define XtCHistorySize           "HistorySize"
 #define XtNpopdownHistorySize    "popsownHistorySize"
@@ -388,6 +400,10 @@
 #define XtCMaxUndoDepth          "MaxUndoDepth"
 #define XtNmaxUndoSize           "maxUndoSize"
 #define XtCMaxUndoSize           "MaxUndoSize"
+#define XtNthemes                "themes"
+#define XtCThemes                "Themes"
+#define XtNsuppressTheme         "suppressTheme"
+#define XtCTheme                 "Theme"
 #define XtNdumpCore              "dumpCore"
 #define XtCDumpCore              "DumpCore"
 #define XtNdebugCoreDumps        "debugCoreDumps"
@@ -403,8 +419,8 @@
 struct AppData {
     String    session;
     String    initial_session;
-    String    debugger;
-    String    debugger_command;
+    const _XtString    debugger;
+    const _XtString    debugger_command;
     Boolean   auto_debugger;
     Boolean   open_selection;
     Boolean   trace;
@@ -431,9 +447,11 @@ struct AppData {
     String    default_font;
     String    variable_width_font;
     String    fixed_width_font;
+    String    data_font;
     Cardinal  default_font_size;
     Cardinal  variable_width_font_size;
     Cardinal  fixed_width_font_size;
+    Cardinal  data_font_size;
     String    font_select_command;
     Cardinal  tab_width;
     Cardinal  lines_above_cursor;
@@ -444,6 +462,7 @@ struct AppData {
     Cardinal  line_number_width;
     Boolean   source_editing;
     Boolean   line_buffered_console;
+    OnOff     console_has_focus;
     String    gdb_display_shortcuts;
     String    dbx_display_shortcuts;
     String    xdb_display_shortcuts;
@@ -465,7 +484,7 @@ struct AppData {
     Boolean   debugger_console;
     Boolean   auto_close_data_window;
     String    plot_command;
-    String    plot_term_type;
+    const _XtString    plot_term_type;
     String    plot_window_class;
     Cardinal  plot_window_delay;
     String    plot_init_commands;
@@ -479,6 +498,9 @@ struct AppData {
     int       display_timeout;
     Boolean   synchronous_gdb;
     Boolean   terminate_on_eof;
+    Boolean   stop_and_continue;
+    int       run_interrupt_delay;
+    int       cont_interrupt_delay;
     Boolean   poll_child_status;
     String    debugger_host;
     String    debugger_rhost;
@@ -521,6 +543,7 @@ struct AppData {
     Cardinal  check_options;
     Boolean   tty_mode;
     OnOff     block_tty_input;
+    OnOff     buffer_gdb_output;
     Cardinal  annotate;
     Boolean   display_glyphs;
     Cardinal  max_glyphs;
@@ -568,6 +591,7 @@ struct AppData {
     Boolean   show_base_display_titles;
     Boolean   show_dependent_display_titles;
     Boolean   cluster_displays;
+    unsigned char display_placement;
     Cardinal  status_history_size;
     Cardinal  popdown_history_size;
     Boolean   sort_popdown_history;
@@ -583,11 +607,11 @@ struct AppData {
     String    button_image_geometry;
     Boolean   flat_toolbar_buttons;
     Boolean   flat_dialog_buttons;
-    String    button_color_key;
-    String    active_button_color_key;
+    const _XtString    button_color_key;
+    const _XtString    active_button_color_key;
     String    splash_screen_color_key;
     Boolean   auto_commands;
-    String    auto_command_prefix;
+    const _XtString    auto_command_prefix;
     int       max_breakpoint_number;
     int       max_display_number;
     Boolean   splash_screen;
@@ -596,11 +620,13 @@ struct AppData {
     BindingStyle select_all_bindings;
     int       max_undo_depth;
     int       max_undo_size;
+    String    themes;
+    String    suppress_theme;
     Boolean   maintenance;
     Boolean   dump_core;
     Boolean   debug_core_dumps;
     int       lesstif_version;
-    String    dddinit_version;
+    const _XtString    dddinit_version;
     String    app_defaults_version;
 };
 
