@@ -1,4 +1,4 @@
-// $Id: ArgNode.h,v 1.10 1999/08/19 11:27:04 andreas Exp $
+// $Id: ArgNode.h,v 1.11 2000/12/11 12:21:47 zeller Exp $
 // ArgNode class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -74,7 +74,7 @@ protected:
 
 public:
     // Constructor
-    ArgNode(unsigned i, char *type = "ArgNode"):
+    ArgNode(unsigned i, const char *type = "ArgNode"):
 	DummyNode(type), _id(i)
     {}
 
