@@ -1,4 +1,4 @@
-// $Id: Box.h,v 1.18 1999/08/19 11:27:06 andreas Exp $
+// $Id: Box.h,v 1.19 2000/12/11 12:21:47 zeller Exp $
 // Box class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -70,7 +70,7 @@ private:
     UniqueId _id;		// Identifier
     BoxSize _size;		// Size
     BoxExtend _extend;		// Extensibility
-    char *_type;		// type
+    const char *_type;		// type
 
     static void epsHeader (ostream& os, 
 			   const BoxRegion& region, 
@@ -107,7 +107,7 @@ public:
 
     // Constructor
     Box(BoxSize s = BoxSize(0, 0), BoxExtend e = BoxExtend(0, 0), 
-	char *t = "Box"):
+	const char *t = "Box"):
 	_id(), _size(s), _extend(e), _type(t), _links(1)
     {}
 
