@@ -1,4 +1,4 @@
-// $Id: BoxEdgeA.h,v 1.5 1999/08/19 11:27:07 andreas Exp $ -*- C++ -*-
+// $Id: BoxEdgeA.h,v 1.6 2000/12/20 12:30:24 zeller Exp $ -*- C++ -*-
 // Edge annotation using boxes
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -64,7 +64,21 @@ public:
 
     virtual ~BoxEdgeAnnotation()
     {
-	_box->unlink();
+	if (_box != 0)
+	    _box->unlink();
+    }
+
+    BoxEdgeAnnotation& operator=(const BoxEdgeAnnotation& src)
+    {
+	Box *new_box = 0;
+	if (src._box != 0)
+	    new_box = src._box->dup();
+
+	if (_box != 0)
+	    _box->unlink();
+	_box = new_box;
+
+	return *this;
     }
 
     // Duplication
