@@ -1,4 +1,4 @@
-// $Id: CallNode.h,v 1.14 2000/02/16 11:32:29 andreas Exp $
+// $Id: CallNode.h,v 1.16 2000/12/11 12:21:47 zeller Exp $
 // Function call VSL nodes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -67,7 +67,7 @@ protected:
     void _dumpTree(ostream& s) const;
 
     // Return name of callee
-    virtual char *func_name() const = 0;
+    virtual const char *func_name() const = 0;
 
     // Flag: Dump function name infix?
     virtual bool isInfix() const { return false; }
@@ -91,7 +91,7 @@ public:
     VSLNode* arg() const { return _arg; }
 
     // Constructor
-    CallNode(VSLNode *a, char *type = "CallNode"):
+    CallNode(VSLNode *a, const char *type = "CallNode"):
 	VSLNode(type), _arg(a)
     {}
 
@@ -122,6 +122,7 @@ public:
     void uncompilePatterns(VSLDef *cdef) const;
     int resolveName(VSLDef *cdef, VSLNode **node, string& name, unsigned id);
     int _resolveNames(VSLDef *cdef, unsigned base);
+    void rebind(const class VSLLib *);
     string firstName() const;
 
     bool isConst() const { return _arg->isConst(); }
