@@ -1,4 +1,4 @@
-// $Id: ConstNode.h,v 1.12 1999/08/19 11:27:13 andreas Exp $
+// $Id: ConstNode.h,v 1.13 2000/12/11 12:21:47 zeller Exp $
 // Constants
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -74,7 +74,7 @@ private:
 
 public:
     // Constructor
-    ConstNode(Box *box, char *type = "ConstNode"): 
+    ConstNode(Box *box, const char *type = "ConstNode"): 
 	VSLNode(type), _box(box)
     {}
 
