@@ -1,4 +1,4 @@
-// $Id: DataDisp.h,v 1.115 1999/12/17 17:56:19 andreas Exp $
+// $Id: DataDisp.h,v 1.123 2000/12/19 00:27:08 zeller Exp $
 // Data Display
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -88,6 +88,7 @@ class DispNode;
 class DispBox;
 class DispValue;
 class RegionGraphNode;
+class ThemeManager;
 
 //-----------------------------------------------------------------------------
 class DataDisp {
@@ -187,6 +188,8 @@ class DataDisp {
 
     static DispValue *selected_value();
     static DispNode  *selected_node();
+    static string selected_pattern();
+    static string pattern(const string& expr, bool shorten = true);
 
     static void open_data_window();
     static void close_data_window();
@@ -207,7 +210,7 @@ class DataDisp {
 
     static void show(Widget dialog, int depth, int more);
 
-    static Widget create_display_dialog(Widget parent, String name,
+    static Widget create_display_dialog(Widget parent, const _XtString name,
 					NewDisplayInfo& info);
 
     static void rotate_value(DispValue *dv, bool all = false);
@@ -245,7 +248,7 @@ class DataDisp {
     static void graph_rotateAct         (Widget, XEvent*, String*, Cardinal*);
     static void graph_dependentAct      (Widget, XEvent*, String*, Cardinal*);
 
-    static void call_selection_proc(Widget, String, XEvent*, String*, Cardinal,
+    static void call_selection_proc(Widget, const _XtString, XEvent*, String*, Cardinal,
 				    SelectionMode mode);
 
     //-----------------------------------------------------------------------
@@ -261,9 +264,10 @@ class DataDisp {
     static MMDesc shortcut_menu[];
     static MMDesc rotate_menu[];
     static MMDesc delete_menu[];
+    static MMDesc theme_menu[];
 
     static const int shortcut_items;
-
+    static const int theme_items;
 
     // Array of shortcut expressions
     static StringArray shortcut_exprs;
@@ -320,6 +324,24 @@ public:
 				 bool verbose = true,
 				 bool prompt = true);
 
+    // Apply THEME on PATTERN.
+    static void apply_themeSQ(const string& theme,
+			      const string& pattern,
+			      bool verbose = true,
+			      bool prompt = true);
+
+    // Unapply THEME on PATTERN.
+    static void unapply_themeSQ(const string& theme,
+				const string& pattern,
+				bool verbose = true,
+				bool prompt = true);
+
+    // Toggle THEME on PATTERN.
+    static void toggle_themeSQ(const string& theme,
+			       const string& pattern,
+			       bool verbose = true,
+			       bool prompt = true);
+
     // Same, but return the appropriate command
     static string new_display_cmd(const string& display_expression,
 				  BoxPoint *pos = 0,
@@ -332,6 +354,12 @@ public:
     static string enable_display_cmd(IntArray& display_nrs);
     static string delete_display_cmd(IntArray& display_nrs);
     static string delete_display_cmd(const string& name);
+    static string apply_theme_cmd(const string& theme, 
+				  const string& pattern);
+    static string unapply_theme_cmd(const string& theme, 
+				    const string& pattern);
+    static string toggle_theme_cmd(const string& theme, 
+				   const string& pattern);
 
     // Same, but use the GDB_COMMAND interface for enqueing commands
     static void new_display(string display_expression,
@@ -374,6 +402,24 @@ public:
 	gdb_command(delete_display_cmd(name), origin);
     }
 
+    static void apply_theme(const string& theme, const string& pattern, 
+			    Widget origin = 0)
+    {
+	gdb_command(apply_theme_cmd(theme, pattern), origin);
+    }
+
+    static void unapply_theme(const string& theme, const string& pattern, 
+			      Widget origin = 0)
+    {
+	gdb_command(unapply_theme_cmd(theme, pattern), origin);
+    }
+
+    static void toggle_theme(const string& theme, const string& pattern, 
+			     Widget origin = 0)
+    {
+	gdb_command(toggle_theme_cmd(theme, pattern), origin);
+    }
+
     // Process 'info display' output in INFO_DISPLAY_ANSWER.  If
     // DEFER_DELETED is set, defer displays that have been deleted.
     static void process_info_display (string& info_display_answer, 
@@ -407,6 +453,9 @@ public:
     // Refresh argument buttons
     static void refresh_args(bool update_arg = false);
 
+    // Set theme manager and refresh display
+    static void set_theme_manager(const ThemeManager& t);
+
 private:
     // Call me back again
     static void again_new_displaySQ (XtPointer client_data, XtIntervalId *id);
@@ -545,6 +594,11 @@ public:
     static void selectAllCB(Widget, XtPointer, XtPointer);
     static void unselectAllCB(Widget, XtPointer, XtPointer);
     static void deleteCB(Widget, XtPointer, XtPointer);
+    static void applyThemeCB(Widget, XtPointer, XtPointer);
+    static void unapplyThemeCB(Widget, XtPointer, XtPointer);
+    static void toggleThemeCB(Widget, XtPointer, XtPointer);
+    static void applyThemeOnThisCB(Widget, XtPointer, XtPointer);
+    static void applyThemeOnAllCB(Widget, XtPointer, XtPointer);
 
     // Helpers for user displays
     static bool have_user_display(const string& name);
