@@ -1,4 +1,4 @@
-// $Id: DispBox.h,v 1.31 1999/08/19 11:27:21 andreas Exp $
+// $Id: DispBox.h,v 1.35 2000/06/16 17:55:15 andreas Exp $
 // Display boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -39,9 +39,11 @@
 
 #include "strclass.h"
 #include "Box.h"
-#include "VSLLib.h"
+#include "ThemeVSLL.h"
 #include "VSLArgList.h"
+#include "DataLink.h"
 #include "DispValue.h"
+#include "ThemeM.h"
 #include "assert.h"
 
 //-----------------------------------------------------------------------------
@@ -62,6 +64,16 @@ private:
 
     static bool is_numeric(const DispValue *dv, const DispValue *parent);
 
+    static struct VSLLibCache *vsllib_cache;
+
+protected:
+    static DataLink data_link;
+    static Data *link_link(Data *);
+    static void link_unlink(Data *);
+    static bool link_selected(Data *);
+    static string link_info(Data *);
+    static string link_name(Data *);
+
 public:
     // Must be initialized from outside!
     static string  vsllib_name;
@@ -77,6 +89,12 @@ public:
     // Initialize VSL library, using BACKGROUND as work proc
     static void init_vsllib(void (*background)() = 0);
 
+    // Mapping of expressions to themes
+    static ThemeManager theme_manager;
+
+    // Clear cache
+    static void clear_vsllib_cache();
+
     // Create a new box.  If DV == 0, create a disabled box.
     DispBox (int disp_nr, const string& title, 
 	     const DispValue *dv = 0, const DispValue *parent = 0);
@@ -91,7 +109,7 @@ public:
     void set_value (const DispValue *dv, const DispValue *parent = 0);
 
     // Set title to NAME; if NAME == "", disable it
-    void set_title(int disp_nr, string name);
+    void set_title(const DispValue *dv, int disp_nr, string name);
 
     bool have_title() const { return title_box != 0; }
 
@@ -103,16 +121,9 @@ private:
     Box *_create_value_box(const DispValue *dv,
 			   const DispValue *parent);
 
-    static VSLLib dummylib;
-    static VSLLib *vsllib_ptr;
-    static VSLLib *vsllib()
-    {
-	if (!vsllib_initialized)
-	    init_vsllib();
-
-	return vsllib_ptr;
-    }
-    
+    static ThemedVSLLib dummylib;
+    static ThemedVSLLib *vsllib_ptr;
+    static VSLLib *vsllib(const DispValue *dv);
 
 protected:
     // Evaluation functions
@@ -121,22 +132,25 @@ protected:
     static void shorten_title(string& title);
 
 public:
-    static Box *eval(const string& func_name, const VSLArgList& args)
+    static Box *eval(const DispValue *dv,
+		     const string& func_name, const VSLArgList& args)
     {
-	return check(func_name, vsllib()->eval(func_name, args.list()));
+	return check(func_name, vsllib(dv)->eval(func_name, args.list()));
     }
-    static Box *eval(const string& func_name, VSLArg args[])
+    static Box *eval(const DispValue *dv,
+		     const string& func_name, VSLArg args[])
     {
-	return check(func_name, vsllib()->eval(func_name, args));
+	return check(func_name, vsllib(dv)->eval(func_name, args));
     }
-    static Box *eval(const string& func_name, 
+    static Box *eval(const DispValue *dv,
+		     const string& func_name, 
 		     VSLArg arg1 = (Box *)0,
 		     VSLArg arg2 = (Box *)0,
 		     VSLArg arg3 = (Box *)0,
 		     VSLArg arg4 = (Box *)0)
     {
 	return check(func_name, 
-		     vsllib()->eval(func_name, arg1, arg2, arg3, arg4));
+		     vsllib(dv)->eval(func_name, arg1, arg2, arg3, arg4));
     }
 };
 
