@@ -1,4 +1,4 @@
-// $Id: DispValue.h,v 1.56 2000/06/06 20:32:37 andreas Exp $
+// $Id: DispValue.h,v 1.57 2001/04/26 19:42:21 zeller Exp $
 // Read and store type and value of a displayed expression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -406,6 +406,9 @@ public:
 
     // Return a title for NAME
     static string make_title(const string& name);
+
+    // Invariant check
+    virtual bool OK() const;
 };
 
 #endif // _DDD_DispValue_h
