@@ -1,4 +1,4 @@
-// $Id: DummyNode.h,v 1.11 1999/08/19 11:27:26 andreas Exp $
+// $Id: DummyNode.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
 // A DummyNode returns a DummyBox
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -67,7 +67,7 @@ protected:
 
 public:
     // Constructor
-    DummyNode(char *type = "DummyNode")
+    DummyNode(const char *type = "DummyNode")
 	: VSLNode(type)
     {}
 
