@@ -1,4 +1,4 @@
-// $Id: GDBAgent.h,v 1.111 2000/01/07 10:58:18 andreas Exp $
+// $Id: GDBAgent.h,v 1.124 2001/01/26 09:24:09 zeller Exp $
 // Communicate with separate GDB process
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -30,13 +30,10 @@
 
 //-----------------------------------------------------------------------------
 // A GDBAgent creates a connection to an inferior GDB via a TTYAgent.
-// There are three ways to send commands to GDB:
+// There are two ways to send commands to GDB:
 // 1. send_user_cmd: is used for user input at the GDB prompt.  GDB output
 //    (partial answers) are processed immediately.
-// 2. send_question: is used for internal communication.  All answers
-//    are buffered until the whole answer is received.  send_question can
-//    only be used if GDB is ready for input.
-// 3. send_qu_array: issues a list of queries to GDB.  The passed function
+// 2. send_qu_array: issues a list of queries to GDB.  The passed function
 //    is called as soon as the last query is processed.  The passed function
 //    must free the memory claimed by the query array.
 //-----------------------------------------------------------------------------
@@ -107,10 +104,6 @@ typedef void (* OAProc) (const string& answer,
 // Called after the whole answer to send_user_cmd has been received
 typedef void (* OACProc) (void* user_data);
 
-// Called from send_question with the complete answer
-typedef void (* OQCProc) (const string& complete_answer,
-			  void*  qu_data);
-
 // Called from send_qu_array with the complete answers
 typedef void (* OQACProc) (const StringArray& complete_answers,
 			   const VoidArray& user_datas,
@@ -130,9 +123,11 @@ const unsigned ReadyForQuestion = TTYAgent_NTypes;
 const unsigned ReadyForCmd      = ReadyForQuestion + 1;
 const unsigned LanguageChanged  = ReadyForCmd + 1;
 const unsigned ReplyRequired    = LanguageChanged + 1;
-const unsigned EchoDetected     = ReplyRequired + 1;
+const unsigned YesNoRequired    = ReplyRequired + 1;
+const unsigned EchoDetected     = YesNoRequired + 1;
 const unsigned AsyncAnswer      = EchoDetected + 1;
-const unsigned Recording        = AsyncAnswer + 1;
+const unsigned ExceptionState   = AsyncAnswer + 1;
+const unsigned Recording        = ExceptionState + 1;
 const unsigned GDBAgent_NTypes  = Recording + 1;
 
 // Handler info
@@ -157,7 +152,6 @@ protected:
     enum State {
 	ReadyWithPrompt,
 	BusyOnCmd, 
-	BusyOnQuestion, 
 	BusyOnQuArray,
 	BusyOnInitialCmds
     };
@@ -193,17 +187,25 @@ private:
     bool _has_examine_command;
     bool _has_rerun_command;
     bool _rerun_clears_args;
+    bool _has_attach_command;
+    bool _has_addproc_command;
+    bool _has_debug_command;
+    bool _is_windriver_gdb;
 
     ProgramLanguage _program_language; // Current program language
 
     bool _verbatim;		// True if in verbatim mode
     bool _recording;		// True if we are recording commands
     bool _detect_echos;		// True if echos are to be detected
+    bool _buffer_gdb_output;	// True if GDB output is to be buffered
+    bool _flush_next_output;	// True if next GDB output is to be flushed
 
     string last_prompt;		// Last prompt received
     string last_written;	// Last command sent
     int echoed_characters;      // # of echoed characters so far (-1: no echo)
 
+    bool exception_state;	// True if exception encountered
+
     GDBAgent& operator = (const GDBAgent&) { assert(0); return *this; }
 
 protected:
@@ -214,7 +216,7 @@ protected:
     static string append_suffix(const string& expr, const string& suffix);
 
     // General trace function
-    void trace(char *prefix, void *call_data) const;
+    void trace(const char *prefix, void *call_data) const;
 
     // Perl specials
     static void munch_perl_array(string& value, bool hash);
@@ -271,10 +273,6 @@ public:
 			     string user_cmd,
 			     void* user_data = 0);
 
-    bool send_question (string  cmd,
-			OQCProc on_question_completion,
-			void*   qu_data);
-
     bool send_qu_array (const StringArray& cmds,
 			const VoidArray& qu_datas,
 			int      qu_count,
@@ -286,10 +284,6 @@ public:
     DebuggerType type()       const { return _type; }
     string title()            const;
     bool isReadyWithPrompt()  const { return state == ReadyWithPrompt; }
-    bool isBusyOnCmd()        const { return state == BusyOnCmd
-					  || state == BusyOnInitialCmds; }
-    bool isBusyOnQuestion()   const { return state == BusyOnQuestion
-					  || state == BusyOnQuArray; }
     string prompt()           const { return last_prompt; }
 
 
@@ -405,6 +399,22 @@ public:
     bool rerun_clears_args() const   { return _rerun_clears_args; }
     bool rerun_clears_args(bool val) { return _rerun_clears_args = val; }
 
+    // True if debugger has `attach' command
+    bool has_attach_command() const   { return _has_attach_command; }
+    bool has_attach_command(bool val) { return _has_attach_command = val; }
+
+    // True if debugger has `addproc' command
+    bool has_addproc_command() const   { return _has_addproc_command; }
+    bool has_addproc_command(bool val) { return _has_addproc_command = val; }
+
+    // True if debugger has `debug' command
+    bool has_debug_command() const   { return _has_debug_command; }
+    bool has_debug_command(bool val) { return _has_debug_command = val; }
+
+    // True if debugger is the Windriver variant of GDB
+    bool is_windriver_gdb() const   { return _is_windriver_gdb; }
+    bool is_windriver_gdb(bool val) { return _is_windriver_gdb = val; }
+
     // Current program language
     ProgramLanguage program_language() const   { return _program_language; }
     ProgramLanguage program_language(ProgramLanguage val) 
@@ -467,8 +477,8 @@ public:
     // True if debugger supports assignments
     bool has_assign_command() const
     {
-	return type() == GDB || type() == XDB || type() == DBX || 
-	       type() == PYDB || type() == PERL;
+	// All debuggers except JDB 1.1 can assign
+	return !(type() == JDB && has_debug_command());
     }
 
     // True if debugger supports calling system functions
@@ -614,6 +624,9 @@ public:
 	return has_condition_command() || type() != JDB;
     }
 
+    // True if arrays are contained in braces
+    bool has_array_braces() const { return !is_ladebug(); }
+
     // True if debugger can disable breakpoints
     bool can_disable() const
     {
@@ -626,6 +639,9 @@ public:
 	return has_enable_command() || has_conditions();
     }
 
+    // True if Ladebug
+    bool is_ladebug() const;
+
     // True if a minimum indent is required.  This is true for
     // scripting languages.
     bool requires_script_indent() const
@@ -646,6 +662,17 @@ public:
     bool detect_echos() const        { return _detect_echos; }
     bool detect_echos(bool val)      { return _detect_echos = val; }
 
+    // True if buffering partial answers
+    bool buffer_gdb_output() const       { return _buffer_gdb_output; }
+    bool buffer_gdb_output(bool val)     { return _buffer_gdb_output = val; }
+
+    // True if next answer is to be flushed
+    bool flush_next_output() const       { return _flush_next_output; }
+    bool flush_next_output(bool val)     { return _flush_next_output = val; }
+
+    // Place quotes around filename FILE if needed
+    string quote_file(const string& file) const;
+
     // Several commands
 				                    // GDB command
 						    // -----------------------
@@ -705,6 +732,10 @@ public:
     // Run program, re-using current arguments
     string rerun_command() const;                   // run
 
+    // Attach to process id PID
+    string attach_command(int pid, const string& file) const;  // attach PID
+    string detach_command(int pid) const;                      // detach
+
     // Default history file
     string history_file() const;                    // GDB: ~/.gdb_history
 
@@ -723,7 +754,11 @@ public:
     // True if ANSWER ends in a prompt
     bool ends_with_prompt(const string& answer);
     bool ends_with_secondary_prompt(const string& answer);
+    bool ends_with_yn(const string& answer);
 
+    // True if exception error message
+    bool is_exception_answer(const string& answer);
+    void set_exception_state(bool state);
 
     // Helpers
     string cmd() const;		// Actual command being executed
@@ -745,7 +780,6 @@ private:
 
     OAProc   _on_answer;
     OACProc  _on_answer_completion;
-    OQCProc  _on_question_completion;
     OQACProc _on_qu_array_completion;
 
     void    init_qu_array (const StringArray& cmds,
@@ -780,6 +814,10 @@ protected:
     static void traceInputHP (Agent *, void *, void *);
     static void traceOutputHP(Agent *, void *, void *);
     static void traceErrorHP (Agent *, void *, void *);
+
+public:    
+    // Terminator
+    virtual void abort();
 };
 
 #endif // _DDD_GDBAgent_h
