@@ -1,4 +1,4 @@
-// $Id: GraphEdge.h,v 1.18 1999/08/19 11:27:30 andreas Exp $
+// $Id: GraphEdge.h,v 1.19 2001/01/09 18:15:22 zeller Exp $
 // GraphEdge Class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -40,6 +40,9 @@
 #include "TypeInfo.h"
 #include "assert.h"
 
+class GraphNode;
+class Graph;
+
 class GraphEdge {
 public:
     DECLARE_TYPE_INFO
