@@ -1,8 +1,8 @@
-// $Id: HintGraphN.h,v 1.12 1998/03/25 12:43:28 zeller Exp $  -*- C++ -*-
+// $Id: HintGraphN.h,v 1.14 1999/08/19 11:27:35 andreas Exp $  -*- C++ -*-
 // HintGraphNode class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_HintGraphNode_h
 #define _DDD_HintGraphNode_h
@@ -81,6 +81,12 @@ public:
 	r = BoxRegion(pos() - gc.hintSize / 2, gc.hintSize);
 	return r;
     }
+
+    // Print
+    virtual void _print(ostream&, const GraphGC&) const 
+    {
+	// Do nothing
+    }
 };
 
 #endif // _DDD_HintGraphNode_h
