@@ -1,4 +1,4 @@
-// $Id: LineBox.h,v 1.11 1999/08/19 11:27:38 andreas Exp $
+// $Id: LineBox.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
 // Line boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -71,7 +71,7 @@ protected:
 			bool context_selected) const = 0;
 
 public:
-    LineBox(BoxCoordinate linethickness = 1, char *t = "LineBox"):
+    LineBox(BoxCoordinate linethickness = 1, const char *t = "LineBox"):
 	PrimitiveBox(BoxSize(0,0), BoxExtend(true, true), t),
 	_linethickness(linethickness)
     {}
