@@ -1,4 +1,4 @@
-// $Id: LineGraphE.h,v 1.20 1999/08/19 11:27:39 andreas Exp $
+// $Id: LineGraphE.h,v 1.21 2000/12/20 12:30:24 zeller Exp $
 // LineGraphEdge class: GraphEdge with drawing capabilities
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -98,6 +98,13 @@ private:
     static void clipToCircle(const BoxRegion& b, int side, 
 			     BoxPoint& p, const BoxPoint& c);
 
+    // Assignment
+    LineGraphEdge& operator=(const LineGraphEdge&)
+    {
+	assert(0);
+	return *this;
+    }
+
 public:
     // Constructor
     LineGraphEdge(GraphNode *f, GraphNode *t, EdgeAnnotation *ann = 0):
