@@ -1,4 +1,4 @@
-// $Id: MatchBox.h,v 1.11 1999/08/19 11:27:43 andreas Exp $ 
+// $Id: MatchBox.h,v 1.12 2000/12/11 12:21:47 zeller Exp $ 
 // Matching boxes (for pattern matching)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -73,7 +73,7 @@ protected:
 
 public:
     // Constructor
-    MatchBox(int d, char *t = "MatchBox"):
+    MatchBox(int d, const char *t = "MatchBox"):
 	DummyBox(t),
 	_data(d)
     {}
