@@ -1,4 +1,4 @@
-// $Id: NameNode.h,v 1.11 1999/08/19 11:27:45 andreas Exp $
+// $Id: NameNode.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
 // VSL Variable names
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -64,7 +64,7 @@ protected:
 
 public:
     // Constructor
-    NameNode(string nm, char *type = "NameNode"):
+    NameNode(string nm, const char *type = "NameNode"):
 	VSLNode(type), _name(nm)
     {}
 
