@@ -1,4 +1,4 @@
-// $Id: PannedGEP.h,v 1.11 2000/11/22 11:40:24 zeller Exp $  -*- C++ -*-
+// $Id: PannedGEP.h,v 1.12 2001/04/25 08:45:52 zeller Exp $  -*- C++ -*-
 // Panned Graph Editor (private part)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -39,9 +39,11 @@
 // Superclasses
 #define new new_w
 #define class class_w
+extern "C" {
 #include <X11/IntrinsicP.h>
 #include <X11/CompositeP.h>
 #include <X11/Xaw/PortholeP.h>
+}
 #undef new
 #undef class
 
