@@ -1,4 +1,4 @@
-// $Id: PlotArea.h,v 1.5 1999/08/19 11:27:46 andreas Exp $ -*- C++ -*-
+// $Id: PlotArea.h,v 1.6 2000/12/20 12:30:24 zeller Exp $ -*- C++ -*-
 // An area to plot upon
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -36,6 +36,7 @@
 #include "strclass.h"
 #include <X11/Intrinsic.h>
 #include "ChunkQueue.h"
+#include "assert.h"
 
 class PlotArea;
 
@@ -79,6 +80,22 @@ class PlotArea {
     void plot_clear   (const char *command);
     void plot_reset   (const char *command);
 
+    // Don't use these
+    PlotArea(PlotArea&)
+	: area(0), dpy(0), win(0),
+	  cx(0), cy(0), px(1), py(1), xscale(0.0), yscale(0.0),
+	  gc(0), font(0), vchar(0), jmode(0), line_type(0), width(0),
+	  type(0), pointsize(1), pending_plots(0), last_commands()
+    {
+	assert(0);
+    }
+
+    PlotArea& operator=(const PlotArea&)
+    {
+	assert(0);
+	return *this;
+    }
+
 protected:
     virtual int do_plot(const char *commands, bool clear);
 
