@@ -1,4 +1,4 @@
-// $Id: ScrolledGE.h,v 1.10 1999/08/19 11:27:50 andreas Exp $  -*- C++ -*-
+// $Id: ScrolledGE.h,v 1.11 2000/12/11 12:21:47 zeller Exp $  -*- C++ -*-
 // Scrolled Graph Editor
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -45,7 +45,7 @@ extern WidgetClass scrolledGraphEditWidgetClass;
 // Declare special access functions
 
 // Create a graph editor with scrollbars; return the graph editor widget ID
-Widget createScrolledGraphEdit(Widget parent, String name, ArgList arglist,
+Widget createScrolledGraphEdit(Widget parent, const _XtString name, ArgList arglist,
 			       Cardinal argcount);
 
 // For a given graph editor W, return its scroller
