@@ -1,4 +1,4 @@
-// $Id: SourceView.h,v 1.147 1999/08/19 11:27:55 andreas Exp $
+// $Id: SourceView.h,v 1.151 2000/12/21 02:05:08 zeller Exp $
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -163,9 +163,9 @@ class SourceView {
 			    Widget& form, Widget& text);
 
     // Refresh displays
-    static void refresh_bp_disp();
-    static void refresh_source_bp_disp();
-    static void refresh_code_bp_disp();
+    static void refresh_bp_disp(bool reset = false);
+    static void refresh_source_bp_disp(bool reset = false);
+    static void refresh_code_bp_disp(bool reset = false);
 
     // Clear breakpoint helpers
     static void clearBP(void *client_data, XtIntervalId *timer);
@@ -371,10 +371,10 @@ class SourceView {
     static StringArray bad_files;
     static bool new_bad_file(const string& file_name);
     static void post_file_error(const string& file_name,
-				string text, String name = 0,
+				string text, const _XtString name = 0,
 				Widget origin = 0);
     static void post_file_warning(const string& file_name,
-				  string text, String name = 0,
+				  string text, const _XtString name = 0,
 				  Widget origin = 0);
 
     // The current directory
@@ -482,7 +482,7 @@ class SourceView {
     static Pixmap pixmap(Widget w, unsigned char *bits, int width, int height);
 
     // Create glyph in FORM_W named NAME from given BITS
-    static Widget create_glyph(Widget form_w, String name, 
+    static Widget create_glyph(Widget form_w, const _XtString name, 
 			       unsigned char *bits, int width, int height);
 
     // Map glyph W in (X, Y)
@@ -587,7 +587,7 @@ private:
     static int max_breakpoint_number_seen;
 
     // Return breakpoint number of BP_INFO; 0 if new; -1 if none
-    static int breakpoint_number(const string& bp_info);
+    static int breakpoint_number(const string& bp_info, string& file);
 
     // Get numbers of selected breakpoints
     static void getBreakpointNumbers(IntArray& numbers);
@@ -917,7 +917,6 @@ public:
 
     // Helpers
     static string full_path(string file);
-    static const char *basename(const char *);
 
     // Edit breakpoint properties.
     static void edit_breakpoint_properties(int bp_nr);
