@@ -1,4 +1,4 @@
-// $Id: SwallowerP.h,v 1.2 1999/08/19 11:27:57 andreas Exp $ -*- C++ -*-
+// $Id: SwallowerP.h,v 1.3 2001/04/26 11:08:07 zeller Exp $ -*- C++ -*-
 // Swallower Widget - swallow a user application
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -50,7 +50,7 @@ extern "C" {
 // The Swallower class record
 
 typedef struct _SwallowerClassPart {
-    caddr_t extension;
+    XtPointer extension;
 } SwallowerClassPart;
 
 typedef struct _SwallowerClassRec {
