@@ -1,8 +1,8 @@
-// $Id: TTYAgent.h,v 1.20 1998/04/02 09:05:37 zeller Exp $ -*- C++ -*-
+// $Id: TTYAgent.h,v 1.22 1999/08/19 11:27:59 andreas Exp $ -*- C++ -*-
 // An agent interface using ptys (pseudo ttys)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_TTYAgent_h
 #define _DDD_TTYAgent_h
@@ -69,7 +69,7 @@ protected:
 
 public:
     // Constructors
-    TTYAgent(XtAppContext app_context, string pth,
+    TTYAgent(XtAppContext app_context, const string& pth,
 	     unsigned nTypes = TTYAgent_NTypes):
         LiterateAgent(app_context, pth, nTypes),
 	_master_tty(), _slave_tty(),
