@@ -1,4 +1,4 @@
-// $Id: TestNode.h,v 1.11 1999/08/19 11:28:00 andreas Exp $
+// $Id: TestNode.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
 // VSL if..then..else..fi construct
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -71,13 +71,13 @@ protected:
     {}
 
     // Dummy functions (never called)
-    char *func_name() const       { assert(0); return "test"; }
+    const char *func_name() const       { assert(0); return "test"; }
     const Box *call(Box *) const  { assert(0); return 0; }
 
 public:
     // Constructor
     TestNode(VSLNode *tst, VSLNode *t, VSLNode *f, 
-	     char *type = "TestNode")
+	     const char *type = "TestNode")
 	: CallNode(new FixListNode(tst, t, f), type)
     {}
 
