@@ -1,4 +1,4 @@
-// $Id: VSLArgList.h,v 1.2 1999/08/19 11:28:04 andreas Exp $ -*- C++ -*-
+// $Id: VSLArgList.h,v 1.3 2000/12/20 12:30:24 zeller Exp $ -*- C++ -*-
 // Passing arguments to VSL
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -34,11 +34,24 @@
 #endif
 
 #include "ListBox.h"
+#include "assert.h"
 
 // A simple wrapper around a ListBox used for arguments
 class VSLArgList {
     ListBox *_list;
 
+    VSLArgList& operator=(const VSLArgList&)
+    {
+	assert(0);
+	return *this;
+    }
+
+    VSLArgList(const VSLArgList&)
+	: _list(0)
+    {
+	assert(0);
+    }
+
 public:
     VSLArgList()
 	: _list(new ListBox)
