@@ -1,7 +1,8 @@
-// $Id: VSLDefList.h,v 1.13 1999/08/19 11:28:05 andreas Exp $
+// $Id: VSLDefList.h,v 1.16 2000/12/19 00:21:47 zeller Exp $
 // List of VSLDefs
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 2000 Universitaet Passau, Germany.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
@@ -59,7 +60,7 @@ private:
 
 public:
     VSLLib *lib;            // Library of this node
-    unsigned hashcode;      // Index into has table of library
+    unsigned hashcode;      // Index into hash table of library
 
     int references;         // #occurrences in VSLNode's
     int self_references;    // #occurrences in own defs (-1: unknown)
@@ -97,6 +98,9 @@ public:
     VSLDef *def(Box *arglist) const;
     VSLDef *firstdef() const { assert (_ndefs == 1); return _first; }
 
+    // Duplicate
+    VSLDefList *dup(const VSLLib *lib) const;
+
     // Resources
     string func_name() const { return _func_name; }
     bool &global()        { return _global; }
@@ -121,10 +125,7 @@ public:
     const Box *eval(Box *arg) const;
 
     // Rename
-    void override()     
-    { 
-	_func_name += '\'';     // Just append a ' to the name
-    }
+    void override();
 
     // Delete defs
     void replace();
@@ -133,7 +134,7 @@ public:
     virtual ~VSLDefList();
 
     // Representation invariant
-    bool OK() const;
+    virtual bool OK() const;
 };
 
 #endif
