@@ -1,4 +1,4 @@
-// $Id: VSLNode.h,v 1.14 1999/08/19 11:28:06 andreas Exp $
+// $Id: VSLNode.h,v 1.16 2000/12/11 12:21:48 zeller Exp $
 // VSL Nodes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -58,7 +58,7 @@ public:
     DECLARE_TYPE_INFO
 
 private:
-    char *_type;    // Type
+    const char *_type;    // Type
 
 protected:
     unsigned _base; // Number of arguments in context
@@ -88,7 +88,7 @@ private:
 
 public:
     // Constructor
-    VSLNode(char *type = "VSLNode")
+    VSLNode(const char *type = "VSLNode")
 	: _type(type), _base(0)
     {}
 
@@ -136,6 +136,8 @@ public:
 	_base = base;
 	return _resolveNames(cdef, base);
     }
+    virtual void rebind(const class VSLLib *) { return; }
+    
 
     virtual string firstName() const          { return ""; }
 
