@@ -1,8 +1,8 @@
-// $Id: acconfig.h.in,v 1.46 2000/06/09 13:09:18 andreas Exp $ -*- C++ -*-
+// $Id: acconfig.h.in,v 1.48 2001/04/26 14:55:09 zeller Exp $ -*- C++ -*-
 // General configuration file.
 
 // Copyright (C) 1995-1999 Technische Universitaet Braunschweig, Germany.
-// Copyright (C) 2000 Universitaet Passau, Germany.
+// Copyright (C) 2000-2001 Universitaet Passau, Germany.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
@@ -59,6 +59,9 @@
 /* Define if your C++ compiler supports the explicit keyword. */
 #undef HAVE_EXPLICIT
 
+/* Define if your C++ compiler supports new C++ casts, such as const_cast */
+#undef HAVE_NEW_CASTS
+
 /* Define if your C++ compiler supports exception handling. */
 #undef HAVE_EXCEPTIONS
 
@@ -89,6 +92,9 @@
 /* Define if your C++ library has an ostrstreambuf::freeze() function. */
 #undef HAVE_FREEZE_OSTRSTREAMBUF
 
+/* Define if the ios::iostate type is defined or declared in <iostream.h>. */
+#undef HAVE_IOSTATE
+
 /* Define if your C++ compiler supports long long types. */
 #undef HAVE_LONG_LONG
 
