@@ -1,8 +1,8 @@
-// $Id: buttons.h,v 1.17 1998/09/18 13:27:41 zeller Exp $ -*- C++ -*-
+// $Id: buttons.h,v 1.19 1999/09/29 08:27:37 andreas Exp $ -*- C++ -*-
 // DDD buttons
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_buttons_h
 #define _DDD_buttons_h
@@ -63,8 +63,8 @@ void dddEditShortcutsCB(Widget, XtPointer, XtPointer);
 // Refresh button editor after external change
 void refresh_button_editor();
 
-// Get a value from GDB
-string gdbValue(const string& expr);
+// Get a value from GDB, using PRINT_COMMAND (default if none)
+string gdbValue(const string& expr, string print_command = "");
 
 // Return changed EXPR that can be used as assignment value
 string assignment_value(const string& expr);
