@@ -1,4 +1,4 @@
-// $Id: comm-manag.h,v 1.26 1999/08/19 11:28:13 andreas Exp $
+// $Id: comm-manag.h,v 1.31 2000/12/21 05:36:53 zeller Exp $
 // GDB communication manager.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -42,6 +42,7 @@
 #endif
 
 #include "GDBAgent.h"
+#include "Command.h"
 
 // Note: `Command.h' is the preferred way of interacting with GDB.
 
@@ -56,10 +57,8 @@ void start_gdb(bool config = true);
 // extra GDB commands to get GDB state.
 void send_gdb_command(string cmd, Widget origin,
 		      OQCProc callback, OACProc extra_callback, void *data,
-		      bool echo, bool verbose, bool prompt, bool check);
-
-// Send user input CMD to GDB (unchanged).
-void send_gdb_ctrl(string cmd, Widget origin = 0);
+		      bool echo, bool verbose, bool prompt, bool check,
+		      bool undo_source);
 
 // Return FALSE if ANSWER is an error message indicating an unknown command
 bool is_known_command(const string& answer);
@@ -82,5 +81,11 @@ string buffered_gdb_output();
 // True if the debuggee is running
 extern bool debuggee_running;
 
+// True if GDB prompts with `(y or n) '
+bool gdb_prompts_y_or_n();
+
+// Configure JDB
+extern void configure_jdb(const string& all_help);
+
 #endif // _DDD_comm_manag_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
