@@ -1,8 +1,9 @@
-/* $Id: ctest.c,v 1.11 1999/09/30 07:18:44 andreas Exp $ */
+/* $Id: ctest.c,v 1.14 2001/01/31 09:34:23 zeller Exp $ */
 /* C Test program */
 
 /*
  * Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+ * Copyright (C) 2000-2001 Universitaet Passau, Germany.
  * Written by Andreas Zeller <zeller@gnu.org>.
  * 
  * This file is part of DDD.
@@ -35,7 +36,7 @@
  */
 
 char ctest_rcsid[] =
-    "$Id: ctest.c,v 1.11 1999/09/30 07:18:44 andreas Exp $";
+    "$Id: ctest.c,v 1.14 2001/01/31 09:34:23 zeller Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -190,6 +191,7 @@ void array_test ()
     static char* twodim [2][3] = {{ "Pioneering", "women", "in"},
 				  { "computer", "science", "!"}};
 
+
     Date dates[4];
     Date* date_ptrs[4];
     date_ptrs[0] = new_date (Thu, 1, 9, 1994);
@@ -202,6 +204,10 @@ void array_test ()
 	dates[i] = *date_ptrs[i];
 	free_date(date_ptrs[i]);
     }
+
+    (void) twodim;		/* Display this */
+    (void) days_of_week;	/* Display this */
+    (void) dates;		/* Display this */
 }
 
 /*--------------------------------------------------------------------------*/
@@ -209,8 +215,8 @@ void array_test ()
 void type_test ()
 {
     Holiday holiday;
-    Date* date = new_date(Sat, 24, 12, 1994);
-    void* voidptr = date;
+    Date *date = new_date(Sat, 24, 12, 1994);
+    void *voidptr = date;
 
     struct Uni {
 	int ii;
@@ -224,6 +230,14 @@ void type_test ()
     double d = 0.0;
     char sc  = 'a';
 
+    uni.ii = 42;
+
+    (void) voidptr;		/* Dereference this */
+    (void) uni;			/* Display this */
+    (void) f;
+    (void) d;
+    (void) sc;
+
     set_holiday(&holiday, Sat, 31, 12, 1994, "May all acquaintance be forgot");
 
     uni.ii  = 7;
