@@ -1,4 +1,4 @@
-// $Id: disp-read.h,v 1.37 1999/09/27 06:05:34 andreas Exp $
+// $Id: disp-read.h,v 1.42 2000/12/19 12:37:16 zeller Exp $
 // Helper functions to process GDB display output
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -51,12 +51,24 @@ bool is_single_display_cmd(const string& cmd, GDBAgent *gdb);
 // True if CMD has no side effects.
 bool is_nop_cmd(const string& cmd);
 
+// True if CMD is `info line' command.
+bool is_info_line_cmd(const string& cmd);
+
 // True if CMD creates a data display
 bool is_display_cmd(const string& cmd);
 
 // True if CMD changes a data display
 bool is_data_cmd(const string& cmd);
 
+// True if CMD is an apply command
+bool is_apply_theme_cmd(const string& cmd);
+
+// True if CMD is an unapply command
+bool is_unapply_theme_cmd(const string& cmd);
+
+// True if CMD is a toggle command
+bool is_toggle_theme_cmd(const string& cmd);
+
 // True if CMD deletes a data display
 bool is_delete_display_cmd(const string& cmd);
 
@@ -66,8 +78,8 @@ bool is_disable_display_cmd(const string& cmd);
 // True if CMD enables a data display
 bool is_enable_display_cmd(const string& cmd);
 
-// True if CMD executes debuggee and shows new displays
-bool is_running_cmd(const string& cmd, GDBAgent *gdb);
+// True if CMD executes debuggee
+bool is_running_cmd(const string& cmd);
 
 // True if CMD changes current execution position
 bool is_pc_cmd(const string& cmd);
@@ -75,6 +87,9 @@ bool is_pc_cmd(const string& cmd);
 // True if CMD starts debuggee
 bool is_run_cmd(const string& cmd);
 
+// True if CMD runs debuggee for an indefinite period of time
+bool is_cont_cmd(const string& cmd);
+
 // True if CMD kills debuggee
 bool is_kill_cmd(const string& cmd);
 
