@@ -1,4 +1,4 @@
-// $Id: exit.h,v 1.19 1999/08/19 11:28:32 andreas Exp $ -*- C++ -*-
+// $Id: exit.h,v 1.21 2000/12/11 12:21:48 zeller Exp $ -*- C++ -*-
 // Exit DDD
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -43,7 +43,7 @@
 extern void ddd_cleanup();
 extern void ddd_show_signal(int sig);
 extern void ddd_show_exception(const char *cls = 0, const char *what = 0);
-extern void ddd_install_fatal(char *program_name = 0);
+extern void ddd_install_fatal(const char *program_name = 0);
 extern void ddd_install_signal();
 extern void ddd_install_x_fatal();
 extern void ddd_install_x_error();
@@ -61,8 +61,9 @@ extern void report_core(ostream& os);
 
 // Helpers
 class Agent;
-extern void gdb_eofHP  (Agent *, void *, void *);
-extern void gdb_diedHP (Agent *, void *, void *);
+extern void gdb_eofHP      (Agent *, void *, void *);
+extern void gdb_diedHP     (Agent *, void *, void *);
+extern void gdb_exceptionHP(Agent *, void *, void *);
 
 // True if GDB is about to exit
 extern bool gdb_is_exiting;
