@@ -1,4 +1,4 @@
-// $Id: gdbinit.h,v 1.10 1999/11/02 15:25:01 andreas Exp $ -*- C++ -*-
+// $Id: gdbinit.h,v 1.12 2000/12/11 12:21:48 zeller Exp $ -*- C++ -*-
 // GDB initialization
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -43,17 +43,23 @@ extern GDBAgent *new_gdb(DebuggerType type,
 			 XtAppContext app_context,
 			 int argc, char *argv[]);
 
-// Guess an appropriate debugger type from ARGC/ARGV.
-// Set SURE if debugger type could be deduced from args.
-extern DebuggerType guess_debugger_type(int argc, char *argv[], bool& sure);
+struct DebuggerInfo {
+    // Guess an appropriate debugger TYPE from ARGC/ARGV.
+    // Set ARG if debugger type could be deduced from arg ARG.
+
+    DebuggerType type;
+    string arg;
+
+    DebuggerInfo(int argc, const char *argv[]);
+};
 
 // Determine debugger type from given DEBUGGER_NAME
 extern bool get_debugger_type(const string& debugger_name, DebuggerType& type);
 
 // Return default program for TYPE
-extern char *default_debugger(const string& debugger_name, DebuggerType type);
+extern const char *default_debugger(const string& debugger_name, DebuggerType type);
 
-inline char *default_debugger(DebuggerType type)
+inline const char *default_debugger(DebuggerType type)
 {
     return default_debugger("", type);
 }
