@@ -1,4 +1,4 @@
-// $Id: hostname.h,v 1.9 1999/08/19 11:28:39 andreas Exp $ -*- C++ -*-
+// $Id: hostname.h,v 1.10 2000/12/11 12:21:48 zeller Exp $ -*- C++ -*-
 // Return `official' name of host
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -30,10 +30,10 @@
 #define _DDD_hostname_h
 
 // Return name of current host
-extern char *hostname();
+extern const char *hostname();
 
 // Return ``official'' network name of HOST (none: current host)
-extern char *fullhostname(char *host = 0);
+extern const char *fullhostname(const char *host = 0);
 
 #endif // _hostname_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
