@@ -1,4 +1,4 @@
-// $Id: mydialogs.h,v 1.21 1999/08/19 11:28:45 andreas Exp $
+// $Id: mydialogs.h,v 1.23 2000/12/11 12:21:48 zeller Exp $
 // Create dialogs to select display expressions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -48,7 +48,7 @@
 
 // Create a selection box with a top-level shell.  This is like
 // XmCreateSelectionDialog, but the parent is a top-level shell.
-Widget createTopLevelSelectionDialog(Widget parent, String name,
+Widget createTopLevelSelectionDialog(Widget parent, const _XtString name,
 				     ArgList args, Cardinal num_args);
 
 // Get the item numbers
@@ -84,5 +84,15 @@ void updateLabelList (Widget  selectionList,
 // Select POS in LIST and make it visible
 void ListSetAndSelectPos(Widget list, int pos);
 
+// Create an array of XmStrings from the list LABEL_LIST of length
+// LIST_LENGTH.  If HIGHLIGHT_TITLE is set, let the first line be bold.
+XmStringTable makeXmStringTable(string label_list[],
+				int list_length, 
+				bool highlight_title = false);
+
+// Free the XmString table XMLIST of length LIST_LENGTH
+void freeXmStringTable(XmStringTable xmlist, int list_length);
+
+
 #endif // _DDD_mydialogs_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
