@@ -1,4 +1,4 @@
-// $Id: regexps.h,v 1.25 2000/01/12 17:38:21 andreas Exp $ -*- C++ -*-
+// $Id: regexps.h,v 1.27 2000/12/19 12:39:22 zeller Exp $ -*- C++ -*-
 // Regular expressions used in DDD
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
@@ -53,6 +53,7 @@ extern const regex rxbreak_cmd;
 extern const regex rxcd_cmd;
 extern const regex rxchain;
 extern const regex rxcolons;
+extern const regex rxcont_cmd;
 extern const regex rxcore;
 extern const regex rxcore_cmd;
 extern const regex rxcrlf;
@@ -164,6 +165,7 @@ extern const regex rxwhen;
 extern const regex rxwhite;
 extern const regex rxxdb;
 extern const regex rxxdbpos;
+extern const regex rxdoubleindex;
 
 #endif // !RUNTIME_REGEX
 
