@@ -1,4 +1,4 @@
-// $Id: settings.h,v 1.27 1999/08/19 11:28:53 andreas Exp $ -*- C++ -*-
+// $Id: settings.h,v 1.29 2000/12/19 00:25:22 zeller Exp $ -*- C++ -*-
 // Modify debugger settings
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -37,6 +37,7 @@
 #include "bool.h"
 #include "strclass.h"
 #include "GDBAgent.h"
+#include "StringA.h"
 #include "options.h"
 
 // Debugger settings
@@ -107,6 +108,19 @@ extern void save_signals_state();
 extern void reset_signals();
 
 
+
+// Theme Handling
+
+// Return all available themes
+void get_themes(StringArray& themes);
+
+// Update theme table
+extern void update_themes();
+
+// Popup themes editor
+extern void dddPopupThemesCB(Widget, XtPointer, XtPointer);
+
+
 // Command Definitions
 
 // True if definitions must be reloaded
