@@ -1,4 +1,4 @@
-// $Id: sigName.h,v 1.9 1999/08/19 11:28:55 andreas Exp $
+// $Id: sigName.h,v 1.10 2000/12/06 17:32:37 zeller Exp $
 // convert signal to name
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -29,7 +29,7 @@
 #ifndef _DDD_sigName_h
 #define _DDD_sigName_h
 
-extern char *sigName(int number);
-extern char *statusName(int number);
+extern const char *sigName(int number);
+extern const char *statusName(int number);
 
 #endif
