@@ -1,30 +1,30 @@
-// $Id: ungrab.h,v 1.3 1997/10/03 10:41:53 zeller Exp $ -*- C++ -*-
+// $Id: ungrab.h,v 1.7 1999/08/19 11:29:00 andreas Exp $ -*- C++ -*-
 // Ungrab frozen mouse pointer
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_ungrab_h
 #define _DDD_ungrab_h
@@ -33,7 +33,10 @@
 #pragma interface
 #endif
 
-extern void ungrab_mouse_pointer();
+#include "bool.h"
+
+// If START is true, initiate grab check.  If START is false, stop it.
+void check_grabs(bool start);
 
 #endif // _DDD_ungrab_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
